@@ -32,7 +32,7 @@ Node* CommentNodeFactory::getNode( const QString &tagContent, Parser *p ) const
 {
   Q_UNUSED( tagContent );
 
-  p->skipPast( QLatin1String( "endcomment" ) );
+  p->skipPast( QStringLiteral( "endcomment" ) );
 
   return new CommentNode( p );
 }
@@ -43,9 +43,8 @@ CommentNode::CommentNode( QObject *parent )
 
 }
 
-void CommentNode::render( OutputStream *stream, Context *c )
+void CommentNode::render( OutputStream *stream, Context *c ) const
 {
   Q_UNUSED( stream );
   Q_UNUSED( c );
 }
-
