@@ -40,11 +40,10 @@ class FirstOfNode : public Node
 public:
   explicit FirstOfNode( QList<FilterExpression> list, QObject *parent = 0 );
 
-  void render( OutputStream *stream, Context *c );
+  void render( OutputStream *stream, Context *c ) const;
 
 private:
   QList<FilterExpression> m_variableList;
 };
 
 #endif
-
