@@ -34,13 +34,13 @@ Node* TemplateTagNodeFactory::getNode( const QString &tagContent, Parser *p ) co
   QStringList expr = smartSplit( tagContent );
   expr.takeAt( 0 );
   if ( expr.size() <= 0 ) {
-    throw Grantlee::Exception( TagSyntaxError, QLatin1String( "'templatetag' statement takes one argument" ) );
+    throw Grantlee::Exception( TagSyntaxError, QStringLiteral( "'templatetag' statement takes one argument" ) );
   }
 
   QString name = expr.first();
 
   if ( !TemplateTagNode::isKeyword( name ) ) {
-    throw Grantlee::Exception( TagSyntaxError, QLatin1String( "Not a template tag" ) );
+    throw Grantlee::Exception( TagSyntaxError, QStringLiteral( "Not a template tag" ) );
   }
 
   return new TemplateTagNode( name, p );
@@ -56,14 +56,14 @@ TemplateTagNode::TemplateTagNode( const QString &name, QObject *parent )
 static QHash<QString, QString> getKeywordMap()
 {
   QHash<QString, QString> map;
-  map.insert( QLatin1String( "openblock" ), QLatin1String( BLOCK_TAG_START ) );
-  map.insert( QLatin1String( "closeblock" ), QLatin1String( BLOCK_TAG_END ) );
-  map.insert( QLatin1String( "openvariable" ), QLatin1String( VARIABLE_TAG_START ) );
-  map.insert( QLatin1String( "closevariable" ), QLatin1String( VARIABLE_TAG_END ) );
-  map.insert( QLatin1String( "openbrace" ), QChar::fromLatin1( '{' ) );
-  map.insert( QLatin1String( "closebrace" ), QChar::fromLatin1( '}' ) );
-  map.insert( QLatin1String( "opencomment" ), QLatin1String( COMMENT_TAG_START ) );
-  map.insert( QLatin1String( "closecomment" ), QLatin1String( COMMENT_TAG_END ) );
+  map.insert( QStringLiteral( "openblock" ), QLatin1String( BLOCK_TAG_START ) );
+  map.insert( QStringLiteral( "closeblock" ), QLatin1String( BLOCK_TAG_END ) );
+  map.insert( QStringLiteral( "openvariable" ), QLatin1String( VARIABLE_TAG_START ) );
+  map.insert( QStringLiteral( "closevariable" ), QLatin1String( VARIABLE_TAG_END ) );
+  map.insert( QStringLiteral( "openbrace" ), QChar::fromLatin1( '{' ) );
+  map.insert( QStringLiteral( "closebrace" ), QChar::fromLatin1( '}' ) );
+  map.insert( QStringLiteral( "opencomment" ), QLatin1String( COMMENT_TAG_START ) );
+  map.insert( QStringLiteral( "closecomment" ), QLatin1String( COMMENT_TAG_END ) );
   return map;
 }
 
@@ -73,7 +73,7 @@ bool TemplateTagNode::isKeyword( const QString &name )
   return map.contains( name );
 }
 
-void TemplateTagNode::render( OutputStream *stream, Context *c )
+void TemplateTagNode::render( OutputStream *stream, Context *c ) const
 {
   Q_UNUSED( c )
   static QHash<QString, QString> map = getKeywordMap();
