@@ -43,7 +43,7 @@ Node* WithLocaleNodeFactory::getNode( const QString &tagContent, Parser *p ) con
   FilterExpression fe( expr.at( 1 ), p );
 
   WithLocaleNode *n = new WithLocaleNode( fe, p );
-  NodeList nodeList = p->parse( n, QLatin1String( "endwith_locale" ) );
+  NodeList nodeList = p->parse( n, QStringLiteral( "endwith_locale" ) );
   n->setNodeList( nodeList );
   p->removeNextToken();
 
@@ -61,7 +61,7 @@ void WithLocaleNode::setNodeList( NodeList nodeList )
   m_list = nodeList;
 }
 
-void WithLocaleNode::render( OutputStream *stream, Context *c )
+void WithLocaleNode::render( OutputStream *stream, Context *c ) const
 {
   const QString name = Grantlee::getSafeString( m_localeName.resolve( c ) ).get();
 
@@ -71,4 +71,3 @@ void WithLocaleNode::render( OutputStream *stream, Context *c )
   c->localizer()->popLocale();
   c->pop();
 }
-
