@@ -23,7 +23,6 @@
 
 #include "exception.h"
 #include "grantlee_config_p.h"
-#include "grantlee_latin1literal_p.h"
 #include "grantlee_version.h"
 #include "scriptabletags.h"
 #include "template_p.h"
@@ -42,9 +41,9 @@ static const char __scriptableLibName[] = "grantlee_scriptabletags";
 Engine::Engine( QObject *parent )
     : QObject( parent ), d_ptr( new EnginePrivate( this ) )
 {
-  d_ptr->m_defaultLibraries << QLatin1String( "grantlee_defaulttags" )
-                            << QLatin1String( "grantlee_loadertags" )
-                            << QLatin1String( "grantlee_defaultfilters" );
+  d_ptr->m_defaultLibraries << QStringLiteral( "grantlee_defaulttags" )
+                            << QStringLiteral( "grantlee_loadertags" )
+                            << QStringLiteral( "grantlee_defaultfilters" );
 
   d_ptr->m_pluginDirs = QCoreApplication::instance()->libraryPaths();
   d_ptr->m_pluginDirs << QString::fromLocal8Bit( GRANTLEE_PLUGIN_PATH );
@@ -57,13 +56,13 @@ Engine::~Engine()
   delete d_ptr;
 }
 
-QList<AbstractTemplateLoader::Ptr> Engine::templateLoaders()
+QList<QSharedPointer<AbstractTemplateLoader> > Engine::templateLoaders()
 {
   Q_D( Engine );
   return d->m_loaders;
 }
 
-void Engine::addTemplateLoader( AbstractTemplateLoader::Ptr loader )
+void Engine::addTemplateLoader( QSharedPointer<AbstractTemplateLoader> loader )
 {
   Q_D( Engine );
   d->m_loaders << loader;
@@ -72,11 +71,11 @@ void Engine::addTemplateLoader( AbstractTemplateLoader::Ptr loader )
 QPair<QString, QString> Engine::mediaUri( const QString &fileName ) const
 {
   Q_D( const Engine );
-  QListIterator<AbstractTemplateLoader::Ptr> it( d->m_loaders );
+  QListIterator<QSharedPointer<AbstractTemplateLoader> > it( d->m_loaders );
 
   QPair<QString, QString> uri;
   while ( it.hasNext() ) {
-    const AbstractTemplateLoader::Ptr loader = it.next();
+    const QSharedPointer<AbstractTemplateLoader> loader = it.next();
     uri = loader->getMediaUri( fileName );
     if ( !uri.second.isEmpty() )
       break;
@@ -155,7 +154,7 @@ void Engine::loadDefaultLibraries()
     d->loadCppLibrary( __scriptableLibName, GRANTLEE_VERSION_MINOR );
     PluginPointer<TagLibraryInterface> library = d->loadCppLibrary( __scriptableLibName, GRANTLEE_VERSION_MINOR );
     if ( !library )
-      throw Grantlee::Exception( TagSyntaxError, QLatin1String( "Could not load scriptable tags library" ) );
+      throw Grantlee::Exception( TagSyntaxError, QStringLiteral( "Could not load scriptable tags library" ) );
 #endif
   }
 
@@ -242,7 +241,7 @@ EnginePrivate::EnginePrivate( Engine *engine )
 QString EnginePrivate::getScriptLibraryName( const QString &name, uint minorVersion ) const
 {
   int pluginIndex = 0;
-  const QString prefix = QLatin1Literal( "/grantlee/" )
+  const QString prefix = QStringLiteral( "/grantlee/" )
                        + QString::number( GRANTLEE_VERSION_MAJOR )
                        + QLatin1Char( '.' )
                        + QString::number( minorVersion )
@@ -252,19 +251,19 @@ QString EnginePrivate::getScriptLibraryName( const QString &name, uint minorVers
     const QString libFileName = nextDir
                               + prefix
                               + name
-                              + QLatin1Literal( ".qs" );
+                              + QStringLiteral( ".qs" );
 
     const QFile file( libFileName );
     if ( !file.exists() )
       continue;
     return libFileName;
   }
-  QList<AbstractTemplateLoader::Ptr>::const_iterator it = m_loaders.constBegin();
-  const QList<AbstractTemplateLoader::Ptr>::const_iterator end = m_loaders.constEnd();
+  QList<QSharedPointer<AbstractTemplateLoader> >::const_iterator it = m_loaders.constBegin();
+  const QList<QSharedPointer<AbstractTemplateLoader> >::const_iterator end = m_loaders.constEnd();
   for ( ; it != end; ++it ) {
     const QPair<QString, QString> pair = ( *it )->getMediaUri( prefix
                                                             + name
-                                                            + QLatin1Literal( ".qs" ) );
+                                                            + QStringLiteral( ".qs" ) );
 
     if ( !pair.first.isEmpty() && !pair.second.isEmpty() ) {
       return pair.first + pair.second;
@@ -313,7 +312,7 @@ PluginPointer<TagLibraryInterface> EnginePrivate::loadCppLibrary( const QString
   while ( m_pluginDirs.size() > pluginIndex ) {
     const QString nextDir = m_pluginDirs.at( pluginIndex++ );
     const QString pluginDirString = nextDir
-                                  + QLatin1Literal( "/grantlee/" )
+                                  + QStringLiteral( "/grantlee/" )
                                   + QString::number( GRANTLEE_VERSION_MAJOR )
                                   + QLatin1Char( '.' )
                                   + QString::number( minorVersion )
@@ -347,9 +346,9 @@ Template Engine::loadByName( const QString &name ) const
 {
   Q_D( const Engine );
 
-  QListIterator<AbstractTemplateLoader::Ptr> it( d->m_loaders );
+  QListIterator<QSharedPointer<AbstractTemplateLoader> > it( d->m_loaders );
   while ( it.hasNext() ) {
-    const AbstractTemplateLoader::Ptr loader = it.next();
+    const QSharedPointer<AbstractTemplateLoader> loader = it.next();
 
     if ( !loader->canLoadTemplate( name ) )
       continue;
