@@ -42,7 +42,7 @@ class EnginePrivate;
   @code
     Engine *engine = new Engine();
 
-    FileSystemTemplateLoader::Ptr loader = FileSystemTemplateLoader::Ptr( new FileSystemTemplateLoader() );
+    auto loader = QSharedPointer<FileSystemTemplateLoader>::create();
     loader->setTemplateDirs( QStringList() << "/usr/share/myapp/templates" );
     engine->addTemplateLoader( loader );
 
@@ -107,7 +107,7 @@ class EnginePrivate;
 
   @author Stephen Kelly <steveire@gmail.com>
 */
-class GRANTLEE_CORE_EXPORT Engine : public QObject
+class GRANTLEE_TEMPLATES_EXPORT Engine : public QObject
 {
   Q_OBJECT
 public:
@@ -124,12 +124,12 @@ public:
   /**
     Returns the TemplateLoaders currently configured on the Engine.
   */
-  QList<AbstractTemplateLoader::Ptr> templateLoaders();
+  QList<QSharedPointer<AbstractTemplateLoader> > templateLoaders();
 
   /**
     Adds @p loader to the TemplateLoaders currently configured on the Engine.
   */
-  void addTemplateLoader( AbstractTemplateLoader::Ptr loader );
+  void addTemplateLoader( QSharedPointer<AbstractTemplateLoader> loader );
 
   /**
     Sets the plugin dirs currently configured on the Engine to @p dirs.
@@ -238,4 +238,3 @@ private:
 }
 
 #endif
-
