@@ -22,12 +22,11 @@
 
 #include "exception.h"
 #include "filter.h"
-#include "grantlee_latin1literal_p.h"
 #include "metatype.h"
 #include "parser.h"
 #include "util.h"
 
-typedef QPair<Grantlee::Filter::Ptr, Grantlee::Variable> ArgFilter;
+typedef QPair<QSharedPointer<Grantlee::Filter>, Grantlee::Variable> ArgFilter;
 
 namespace Grantlee
 {
@@ -60,20 +59,20 @@ static QRegExp getFilterRegexp()
   const QString filterSep( QRegExp::escape( QChar::fromLatin1( FILTER_SEPARATOR ) ) );
   const QString argSep( QRegExp::escape( QChar::fromLatin1( FILTER_ARGUMENT_SEPARATOR ) ) );
 
-  const QLatin1Literal varChars( "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_." );
-  const QLatin1Literal numChars( "[-+\\.]?\\d[\\d\\.e]*" );
-  const QString i18nOpen( QRegExp::escape( QLatin1String( "_(" ) ) );
-  const QLatin1Literal doubleQuoteStringLiteral( "\"[^\"\\\\]*(?:\\\\.[^\"\\\\]*)*\"" );
-  const QLatin1Literal singleQuoteStringLiteral( "\'[^\'\\\\]*(?:\\\\.[^\'\\\\]*)*\'" );
-  const QString i18nClose( QRegExp::escape( QLatin1String( ")" ) ) );
-  const QString variable = QLatin1Char( '[' ) + varChars + QLatin1Literal( "]+");
+  const QLatin1String varChars( "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_." );
+  const QLatin1String numChars( "[-+\\.]?\\d[\\d\\.e]*" );
+  const QString i18nOpen( QRegExp::escape( QStringLiteral( "_(" ) ) );
+  const QLatin1String doubleQuoteStringLiteral( "\"[^\"\\\\]*(?:\\\\.[^\"\\\\]*)*\"" );
+  const QLatin1String singleQuoteStringLiteral( "\'[^\'\\\\]*(?:\\\\.[^\'\\\\]*)*\'" );
+  const QString i18nClose( QRegExp::escape( QStringLiteral( ")" ) ) );
+  const QString variable = QLatin1Char( '[' ) + varChars + QStringLiteral( "]+");
 
-  const QString localizedExpression = QLatin1Literal( "(?:" ) + i18nOpen + doubleQuoteStringLiteral + i18nClose + QLatin1Char( '|' )
+  const QString localizedExpression = QStringLiteral( "(?:" ) + i18nOpen + doubleQuoteStringLiteral + i18nClose + QLatin1Char( '|' )
                                                               + i18nOpen + singleQuoteStringLiteral + i18nClose + QLatin1Char( '|' )
                                                               + i18nOpen + numChars                 + i18nClose + QLatin1Char( '|' )
                                                               + i18nOpen + variable                 + i18nClose + QLatin1Char( ')' );
 
-  const QString constantString = QLatin1Literal( "(?:" ) + doubleQuoteStringLiteral + QLatin1Char( '|' )
+  const QString constantString = QStringLiteral( "(?:" ) + doubleQuoteStringLiteral + QLatin1Char( '|' )
                                                          + singleQuoteStringLiteral
                                    + QLatin1Char( ')' );
 
@@ -81,9 +80,9 @@ static QRegExp getFilterRegexp()
                                + QLatin1Char( '^' ) + localizedExpression + QLatin1Char( '|' )
                                + QLatin1Char( '^' ) + variable + QLatin1Char( '|' )
                                + numChars + QLatin1Char( '|' )
-                               + filterSep + QLatin1Literal( "\\w+|" )
+                               + filterSep + QStringLiteral( "\\w+|" )
                                + argSep
-                               + QLatin1Literal( "(?:" )
+                               + QStringLiteral( "(?:" )
                                  + constantString + QLatin1Char( '|' ) + localizedExpression
                                  + QLatin1Char( '|' )
                                  + variable
@@ -91,7 +90,7 @@ static QRegExp getFilterRegexp()
                                  + numChars
                                  + QLatin1Char( '|' )
                                  + filterSep
-                               + QLatin1Literal( "\\w+)" );
+                               + QStringLiteral( "\\w+)" );
 
   return QRegExp( filterRawString );
 }
@@ -110,7 +109,7 @@ FilterExpression::FilterExpression( const QString &varString, Parser *parser )
 
   static const QRegExp sFilterRe = getFilterRegexp();
 
-  // This is one fo the few contstructors that can throw so we make sure to delete its d->pointer.
+  // This is one fo the few constructors that can throw so we make sure to delete its d->pointer.
   try {
     while ( ( pos = sFilterRe.indexIn( vs, pos ) ) != -1 ) {
       len = sFilterRe.matchedLength();
@@ -124,14 +123,19 @@ FilterExpression::FilterExpression( const QString &varString, Parser *parser )
 
       if ( subString.startsWith( QLatin1Char( FILTER_SEPARATOR ) ) ) {
         subString = subString.right( ssSize - 1 );
-        Filter::Ptr f = parser->getFilter( subString );
+        QSharedPointer<Filter> f = parser->getFilter( subString );
 
         Q_ASSERT( f );
 
         d->m_filterNames << subString;
-        d->m_filters << qMakePair<Filter::Ptr, Variable>( f, Variable() );
+        d->m_filters << qMakePair<QSharedPointer<Filter>, Variable>( f, Variable() );
 
       } else if ( subString.startsWith( QLatin1Char( FILTER_ARGUMENT_SEPARATOR ) ) ) {
+        if (d->m_filters.isEmpty() || d->m_filters.last().second.isValid()) {
+            const QString remainder = vs.right( vs.size() - lastPos );
+            throw Grantlee::Exception( TagSyntaxError,
+                QString::fromLatin1( "Could not parse the remainder, %1 from %2" ).arg( remainder ).arg( varString ) );
+        }
         subString = subString.right( ssSize - 1 );
         const int lastFilter = d->m_filters.size();
         if ( subString.startsWith( QLatin1Char( FILTER_SEPARATOR ) ) )
@@ -205,7 +209,7 @@ QVariant FilterExpression::resolve( OutputStream *stream, Context *c ) const
   QVector<ArgFilter>::const_iterator it = d->m_filters.constBegin();
   const QVector<ArgFilter>::const_iterator end = d->m_filters.constEnd();
   for ( ; it != end; ++it ) {
-    Filter::Ptr filter = it->first;
+    QSharedPointer<Filter> filter = it->first;
     filter->setStream( stream );
     const Variable argVar = it->second;
     QVariant arg = argVar.resolve( c );
@@ -252,7 +256,9 @@ QVariant FilterExpression::resolve( Context *c ) const
 QVariantList FilterExpression::toList( Context *c ) const
 {
   const QVariant var = resolve( c );
-  return MetaType::toVariantList( var );
+  if (!var.canConvert<QVariantList>())
+    return QVariantList();
+  return var.value<QVariantList>();
 }
 
 bool FilterExpression::isTrue( Context *c ) const
@@ -265,4 +271,3 @@ QStringList FilterExpression::filters() const
   Q_D( const FilterExpression );
   return d->m_filterNames;
 }
-
