@@ -64,7 +64,7 @@ Node::~Node()
   delete d_ptr;
 }
 
-void Node::streamValueInContext( OutputStream *stream, const QVariant& input, Context* c )
+void Node::streamValueInContext( OutputStream *stream, const QVariant& input, Context* c ) const
 {
   Grantlee::SafeString inputString;
   if ( input.type() == QVariant::List ) {
@@ -155,7 +155,7 @@ bool NodeList::containsNonText() const
   return m_containsNonText;
 }
 
-void NodeList::render( OutputStream *stream, Context *c )
+void NodeList::render( OutputStream *stream, Context *c ) const
 {
   for ( int i = 0; i < this->size(); ++i ) {
     this->at( i )->render( stream, c );
@@ -188,7 +188,14 @@ QList< FilterExpression > AbstractNodeFactory::getFilterExpressionList( const QS
 
 QStringList AbstractNodeFactory::smartSplit( const QString &str ) const
 {
-  const QRegExp r( QLatin1String( "("                   // match
+#if defined(Q_CC_MSVC)
+// MSVC doesn't like static string concatenations like L"foo" "bar", as
+// results from QStringLiteral, so use QLatinString here instead.
+#define STRING_LITERAL QLatinString
+#else
+#define STRING_LITERAL QStringLiteral
+#endif
+  const QRegExp r( STRING_LITERAL( "("                   // match
                     "(?:[^\\s\\\'\\\"]*"                // things that are not whitespace or escaped quote chars
                       "(?:"                             // followed by
                         "(?:\""                         // Either a quote starting with "
@@ -203,6 +210,8 @@ QStringList AbstractNodeFactory::smartSplit( const QString &str ) const
                   ")"                                   // End match
                 ) );
 
+#undef STRING_LITERAL
+
   QStringList l;
   int count = 0;
   int pos = 0;
