@@ -32,7 +32,7 @@ VariableNode::VariableNode( const FilterExpression &fe, QObject *parent )
 {
 }
 
-void VariableNode::render( OutputStream *stream, Context *c )
+void VariableNode::render( OutputStream *stream, Context *c ) const
 {
   const QVariant v = m_filterExpression.resolve( c );
   if ( !v.isValid() )
