@@ -95,6 +95,8 @@ SafeString::NestedString::NestedString( const QString &content, SafeString *safe
 
 SafeString& SafeString::operator=( const SafeString &str )
 {
+  if (&str == this)
+    return *this;
   m_nestedString = str.m_nestedString;
   m_nestedString.m_safeString = this;
   m_safety = str.m_safety;
@@ -104,14 +106,14 @@ SafeString& SafeString::operator=( const SafeString &str )
 
 SafeString SafeString::operator+( const QString &str )
 {
-  return SafeString( m_nestedString + str, IsNotSafe );
+  return SafeString( static_cast<QString>(m_nestedString) + str, IsNotSafe );
 }
 
 SafeString SafeString::operator+( const SafeString &str )
 {
   if ( !str.isSafe() )
-    return SafeString( m_nestedString + str.get(), IsNotSafe );
-  return SafeString( m_nestedString + str.get(), m_safety );
+    return SafeString( static_cast<QString>(m_nestedString) + static_cast<QString>(str.get()), IsNotSafe );
+  return SafeString( static_cast<QString>(m_nestedString) + static_cast<QString>(str.get()), m_safety );
 }
 
 SafeString &SafeString::operator+=( const QString &str )
@@ -173,22 +175,6 @@ SafeString& SafeString::NestedString::append( const QLatin1String &str )
   return *m_safeString;
 }
 
-#ifndef GRANTLEE_NO_CAST_FROM_ASCII
-SafeString& SafeString::NestedString::append( const QByteArray &ba )
-{
-  QString::append( ba );
-  m_safeString->m_safety = IsNotSafe;
-  return *m_safeString;
-}
-
-SafeString& SafeString::NestedString::append( const char *str )
-{
-  QString::append( str );
-  m_safeString->m_safety = IsNotSafe;
-  return *m_safeString;
-}
-#endif
-
 SafeString& SafeString::NestedString::append( const QChar ch )
 {
   QString::append( ch );
@@ -290,22 +276,6 @@ SafeString& SafeString::NestedString::prepend( const QLatin1String &str )
   return *m_safeString;
 }
 
-#ifndef GRANTLEE_NO_CAST_FROM_ASCII
-SafeString& SafeString::NestedString::prepend( const QByteArray &ba )
-{
-  QString::prepend( ba );
-  m_safeString->m_safety = IsNotSafe;
-  return *m_safeString;
-}
-
-SafeString& SafeString::NestedString::prepend( const char *str )
-{
-  QString::prepend( str );
-  m_safeString->m_safety = IsNotSafe;
-  return *m_safeString;
-}
-#endif
-
 SafeString& SafeString::NestedString::prepend( QChar ch )
 {
   QString::prepend( ch );
