@@ -25,10 +25,6 @@
 
 #include <QtCore/QHash>
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-#define Q_PLUGIN_METADATA(p)
-#endif
-
 namespace Grantlee
 {
 class AbstractNodeFactory;
@@ -103,6 +99,6 @@ public:
 
 }
 
-Q_DECLARE_INTERFACE( Grantlee::TagLibraryInterface, "org.kde.grantlee.TagLibraryInterface/1.0" )
+Q_DECLARE_INTERFACE( Grantlee::TagLibraryInterface, "org.grantlee.TagLibraryInterface/1.0" )
 
 #endif
