@@ -24,9 +24,7 @@
 #include "engine.h"
 #include "template.h"
 
-#if QT_VERSION < 0x040600
 #include <QtCore/QPointer>
-#endif
 
 namespace Grantlee
 {
@@ -37,31 +35,22 @@ class TemplatePrivate
 {
   TemplatePrivate( Engine const *engine, bool smartTrim, TemplateImpl *t )
       : q_ptr( t ), m_error( NoError ), m_smartTrim( smartTrim )
-#if QT_VERSION >= 0x040600
       , m_engine( engine )
-#endif
   {
-#if QT_VERSION < 0x040600
-    m_engine = const_cast<Engine *>( engine );
-#endif
   }
 
   void parse();
   NodeList compileString( const QString &str );
-  void setError( Error type, const QString &message );
+  void setError( Error type, const QString &message ) const;
 
   Q_DECLARE_PUBLIC( TemplateImpl )
   TemplateImpl * const q_ptr;
 
-  Error m_error;
-  QString m_errorString;
+  mutable Error m_error;
+  mutable QString m_errorString;
   NodeList m_nodeList;
   bool m_smartTrim;
-#if QT_VERSION < 0x040600
-  QPointer<Engine> m_engine;
-#else
-  QWeakPointer<Engine const> m_engine;
-#endif
+  QPointer<const Engine> m_engine;
 
   friend class Grantlee::Engine;
   friend class Parser;
@@ -71,4 +60,3 @@ class TemplatePrivate
 }
 
 #endif
-
