@@ -20,7 +20,6 @@
 
 #include "util.h"
 
-#include "grantlee_latin1literal_p.h"
 #include "metaenumvariable_p.h"
 #include "metatype.h"
 
@@ -29,9 +28,9 @@
 QString Grantlee::unescapeStringLiteral( const QString &input )
 {
   return input.mid( 1, input.size() - 2 )
-         .replace( QLatin1String( "\\\'" ), QChar::fromLatin1( '\'' ) )
-         .replace( QLatin1String( "\\\"" ), QChar::fromLatin1( '"' ) )
-         .replace( QLatin1String( "\\\\" ), QChar::fromLatin1( '\\' ) );
+         .replace( QStringLiteral( "\\\'" ), QChar::fromLatin1( '\'' ) )
+         .replace( QStringLiteral( "\\\"" ), QChar::fromLatin1( '"' ) )
+         .replace( QStringLiteral( "\\\\" ), QChar::fromLatin1( '\\' ) );
 }
 
 bool Grantlee::variantIsTrue( const QVariant &variant )
@@ -73,11 +72,6 @@ bool Grantlee::variantIsTrue( const QVariant &variant )
   return !getSafeString( variant ).get().isEmpty();
 }
 
-QVariantList Grantlee::variantToList( const QVariant &var )
-{
-  return MetaType::toVariantList( var );
-}
-
 Grantlee::SafeString Grantlee::markSafe( const Grantlee::SafeString &input )
 {
   Grantlee::SafeString sret = input;
@@ -172,7 +166,7 @@ Grantlee::SafeString Grantlee::toString( const QVariantList &list )
   while ( it != end ) {
     const QVariant item = *it;
     if ( isSafeString( item ) ) {
-      output += QLatin1Literal( "u\'" )
+      output += QStringLiteral( "u\'" )
               + static_cast<QString>( getSafeString( item ).get() )
               + QLatin1Char( '\'' );
     }
@@ -189,10 +183,9 @@ Grantlee::SafeString Grantlee::toString( const QVariantList &list )
       output += static_cast<QString>( toString( item.toList() ).get() );
     }
     if ( ( it + 1 ) != end )
-      output += QLatin1String( ", " );
+      output += QStringLiteral( ", " );
     ++it;
   }
 
   return output.append( QLatin1Char( ']' ) );
 }
-
