@@ -36,7 +36,7 @@ Node* IncludeNodeFactory::getNode( const QString &tagContent, Parser *p ) const
   QStringList expr = smartSplit( tagContent );
 
   if ( expr.size() != 2 )
-    throw Grantlee::Exception( TagSyntaxError, QLatin1String( "Error: Include tag takes only one argument" ) );
+    throw Grantlee::Exception( TagSyntaxError, QStringLiteral( "Error: Include tag takes only one argument" ) );
 
   QString includeName = expr.at( 1 );
   int size = includeName.size();
@@ -53,7 +53,7 @@ IncludeNode::IncludeNode( const FilterExpression &fe, QObject *parent )
 {
 }
 
-void IncludeNode::render( OutputStream *stream, Context *c )
+void IncludeNode::render( OutputStream *stream, Context *c ) const
 {
   QString filename = getSafeString( m_filterExpression.resolve( c ) );
 
@@ -79,7 +79,7 @@ ConstantIncludeNode::ConstantIncludeNode( const QString &name, QObject *parent )
   m_name = name;
 }
 
-void ConstantIncludeNode::render( OutputStream *stream, Context *c )
+void ConstantIncludeNode::render( OutputStream *stream, Context *c ) const
 {
   TemplateImpl *ti = containerTemplate();
 
