@@ -29,8 +29,6 @@
 #include "exception.h"
 #include "parser.h"
 
-Q_DECLARE_METATYPE( Engine* )
-
 QScriptValue nodeToScriptValue( QScriptEngine *engine, Node* const &node )
 {
   return engine->newQObject( node );
@@ -58,7 +56,7 @@ QScriptValue ScriptableNodeConstructor( QScriptContext *context,
 
   concreteNode.call( concreteNode, args );
 
-  QScriptValue renderMethod = concreteNode.property( QLatin1String( "render" ) );
+  QScriptValue renderMethod = concreteNode.property( QStringLiteral( "render" ) );
 
   ScriptableNode *object = new ScriptableNode( engine );
   object->setObjectName( scriptableNodeName );
@@ -85,7 +83,7 @@ void ScriptableNode::init( const QScriptValue &concreteNode,
   m_renderMethod = renderMethod;
 }
 
-void ScriptableNode::render( OutputStream *stream, Context *c )
+void ScriptableNode::render( OutputStream *stream, Context *c ) const
 {
   ScriptableContext sc( c );
   QScriptValue contextObject = m_scriptEngine->newQObject( &sc );
@@ -94,7 +92,7 @@ void ScriptableNode::render( OutputStream *stream, Context *c )
   args << contextObject;
 
   // Call the render method in the context of the concreteNode
-  QScriptValue value = m_renderMethod.call( m_concreteNode, args );
+  QScriptValue value = const_cast<QScriptValue&>(m_renderMethod).call( m_concreteNode, args );
 
   if ( value.isValid() && !value.isUndefined() )
     ( *stream ) << value.toString();
