@@ -40,8 +40,6 @@ typedef QSharedPointer<QScriptEngine> ScriptEnginePointer;
 
 using namespace Grantlee;
 
-Q_DECLARE_METATYPE( Grantlee::Node* )
-
 QScriptValue ScriptableNodeConstructor( QScriptContext *context,
                                         QScriptEngine *engine );
 
@@ -61,7 +59,7 @@ public:
 
   QScriptEngine* engine();
 
-  void render( OutputStream *stream, Context *c );
+  void render( OutputStream *stream, Context *c ) const;
 
 private:
   QScriptEngine* m_scriptEngine;
