@@ -28,8 +28,6 @@
 #include "node.h"
 #include "scriptablecontext.h"
 
-Q_DECLARE_METATYPE( Engine* )
-
 QScriptValue ScriptableTemplateConstructor( QScriptContext *context,
     QScriptEngine *engine )
 {
@@ -53,7 +51,7 @@ ScriptableTemplate::ScriptableTemplate( Grantlee::Template t, QObject* parent )
 
 }
 
-QString ScriptableTemplate::render( ScriptableContext* c )
+QString ScriptableTemplate::render( ScriptableContext* c ) const
 {
   return m_template->render( c->context() );
 }
