@@ -25,27 +25,14 @@
 #include "metatype.h"
 #include "test_macros.h"
 
-#include <QtTest/QtTest>
+#include <QtTest/QTest>
 #include <QtCore/QVariant>
+#include <QtCore/QQueue>
+#include <QtCore/QStack>
+#include <QtCore/QLinkedList>
+#include "coverageobject.h"
 
-typedef QObject* QObjectStar;
-
-DECLARE_TYPE_CONTAINERS( qint32 )
-#ifndef MINIMAL_CONTAINER_TESTS
-DECLARE_TYPE_CONTAINERS( QVariant )
-DECLARE_TYPE_CONTAINERS( qint16 )
-DECLARE_TYPE_CONTAINERS( qint64 )
-DECLARE_TYPE_CONTAINERS( quint16 )
-DECLARE_TYPE_CONTAINERS( quint32 )
-DECLARE_TYPE_CONTAINERS( quint64 )
-DECLARE_TYPE_CONTAINERS( float )
-DECLARE_TYPE_CONTAINERS( double )
-DECLARE_TYPE_CONTAINERS( QString )
-DECLARE_TYPE_CONTAINERS( QDateTime )
-DECLARE_TYPE_CONTAINERS( QObjectStar )
-#endif
-
-class TestGenericContainers : public QObject
+class TestGenericContainers : public CoverageObject
 {
   Q_OBJECT
 public:
@@ -56,7 +43,7 @@ private Q_SLOTS:
 };
 
 TestGenericContainers::TestGenericContainers( QObject* parent )
-  : QObject( parent )
+  : CoverageObject(parent )
 {
 
 }
@@ -178,49 +165,49 @@ struct ContainerPopulator<std::map<QString, T> >
 template<typename T>
 QString getTemplate()
 {
-  return QLatin1String( "{% for item in container %}{{ item }},{% endfor %}" );
+  return QStringLiteral( "{{ container.size }};{{ container.count }};{% for item in container %}{{ item }},{% endfor %}" );
 }
 
 template<>
 QString getTemplate<QDateTime>()
 {
-  return QLatin1String( "{% for item in container %}{{ item|date }},{% endfor %}" );
+  return QStringLiteral( "{{ container.size }};{{ container.count }};{% for item in container %}{{ item|date }},{% endfor %}" );
 }
 
 template<>
 QString getTemplate<QObject*>()
 {
-  return QLatin1String( "{% for item in container %}{{ item.objectName }},{% endfor %}" );
+  return QStringLiteral( "{{ container.size }};{{ container.count }};{% for item in container %}{{ item.objectName }},{% endfor %}" );
 }
 
 template<typename T>
 QString getAssociativeTemplate()
 {
-  return QLatin1String( "{% for item in container.values %}{{ item }},{% endfor %}" );
+  return QStringLiteral( "{{ container.size }};{{ container.count }};{% for item in container.values %}{{ item }},{% endfor %}" );
 }
 
 template<>
 QString getAssociativeTemplate<QDateTime>()
 {
-  return QLatin1String( "{% for item in container.values %}{{ item|date }},{% endfor %}" );
+  return QStringLiteral( "{{ container.size }};{{ container.count }};{% for item in container.values %}{{ item|date }},{% endfor %}" );
 }
 
 template<>
 QString getAssociativeTemplate<QObject*>()
 {
-  return QLatin1String( "{% for item in container.values %}{{ item.objectName }},{% endfor %}" );
+  return QStringLiteral( "{{ container.size }};{{ container.count }};{% for item in container.values %}{{ item.objectName }},{% endfor %}" );
 }
 
 template <typename T>
 QStringList getResults()
 {
-  return QStringList() << QLatin1String( "9," ) << QLatin1String( "7," ) << QLatin1String( "5," );
+  return QStringList() << QStringLiteral( "3;3;" ) << QStringLiteral( "9," ) << QStringLiteral( "7," ) << QStringLiteral( "5," );
 }
 
 template<>
 QStringList getResults<QDateTime>()
 {
-  return QStringList() << QLatin1String( "Jan. 1, 1970," ) << QLatin1String( "Jan. 2, 1970," ) << QLatin1String( "Jan. 3, 1970," );
+  return QStringList() << QStringLiteral( "3;3;" ) << QStringLiteral( "Jan. 1, 1970," ) << QStringLiteral( "Jan. 2, 1970," ) << QStringLiteral( "Jan. 3, 1970," );
 }
 
 template<typename Container, typename T = typename Container::value_type>
@@ -284,15 +271,14 @@ void cleanupAssociative( Container c )
 
 void testContainer( const QString &stringTemplate, const QVariant &containerVariant, const QStringList &expectedResults, bool unordered )
 {
-  GRANTLEE_METATYPE_INITIALIZE
   Grantlee::Engine engine;
 
-  engine.setPluginPaths( QStringList() << QLatin1String( GRANTLEE_PLUGIN_PATH ) );
+  engine.setPluginPaths( QStringList() << QStringLiteral( GRANTLEE_PLUGIN_PATH ) );
 
   Grantlee::Context c;
-  c.insert( QLatin1String( "container" ), containerVariant );
+  c.insert( QStringLiteral( "container" ), containerVariant );
 
-  Grantlee::Template t1 = engine.newTemplate( stringTemplate, QLatin1String( "template1" ) );
+  Grantlee::Template t1 = engine.newTemplate( stringTemplate, QStringLiteral( "template1" ) );
 
   QString result = t1->render( &c );
   if (!unordered)
@@ -302,6 +288,12 @@ void testContainer( const QString &stringTemplate, const QVariant &containerVari
     Q_FOREACH (const QString &expectedResult, expectedResults)
       QVERIFY(result.contains(expectedResult));
   }
+
+  Grantlee::Template t2 = engine.newTemplate( QStringLiteral( "-{{ container.doesnotexist }}-" ), QStringLiteral( "template2" ) );
+
+  QString result2 = t2->render( &c );
+
+  QCOMPARE( result2, QStringLiteral( "--" ) );
 }
 
 template<typename Container>
@@ -340,6 +332,7 @@ void doTestNonHashableContainers()
   doTestSequentialContainer<QLinkedList<T> >();
   doTestSequentialContainer<QQueue<T> >();
   doTestSequentialContainer<QStack<T> >();
+  doTestSequentialContainer<std::list<T> >();
   doTestAssociativeContainer<QMap<qint32, T> >();
   doTestAssociativeContainer<std::map<qint32, T> >();
   doTestAssociativeContainer<QHash<qint32, T> >( true );
