@@ -32,8 +32,8 @@
 using namespace Grantlee;
 
 #define INIT_LOCALIZER(localizer)                                \
-localizer->setAppTranslatorPrefix(QLatin1String( "test_" ) );    \
-localizer->setAppTranslatorPath(QLatin1String( ":/" ) );         \
+localizer->setAppTranslatorPrefix(QStringLiteral( "test_" ) );    \
+localizer->setAppTranslatorPath(QStringLiteral( ":/" ) );         \
 
 class TestInternationalization : public CoverageObject
 {
@@ -49,7 +49,7 @@ public:
       en_USLocalizer(new QtLocalizer(QLocale(QLocale::English, QLocale::UnitedStates))),
       m_engine(new Engine(this))
   {
-    m_engine->setPluginPaths( QStringList() << QLatin1String( GRANTLEE_PLUGIN_PATH ) );
+    m_engine->setPluginPaths( QStringList() << QStringLiteral( GRANTLEE_PLUGIN_PATH ) );
     INIT_LOCALIZER(cLocalizer)
     INIT_LOCALIZER(deLocalizer)
     INIT_LOCALIZER(frLocalizer)
@@ -57,20 +57,20 @@ public:
     INIT_LOCALIZER(en_USLocalizer)
     {
       QTranslator *deTranslator = new QTranslator(this);
-      const bool result = deTranslator->load( QLatin1String( ":/test_de_DE" ) );
+      const bool result = deTranslator->load( QStringLiteral( ":/test_de_DE" ) );
       Q_UNUSED(result);
       Q_ASSERT(result);
-      deLocalizer->installTranslator(deTranslator, QLatin1String( "de_DE" ) );
+      deLocalizer->installTranslator(deTranslator, QStringLiteral( "de_DE" ) );
     }
 
     {
       QTranslator *frTranslator = new QTranslator(this);
-      const bool result = frTranslator->load( QLatin1String( ":/test_fr_FR.qm" ) );
+      const bool result = frTranslator->load( QStringLiteral( ":/test_fr_FR.qm" ) );
       Q_UNUSED(result);
       Q_ASSERT(result);
-      frLocalizer->installTranslator(frTranslator, QLatin1String( "fr_FR" ) );
+      frLocalizer->installTranslator(frTranslator, QStringLiteral( "fr_FR" ) );
     }
-    m_engine->addDefaultLibrary(QLatin1String("grantlee_i18ntags"));
+    m_engine->addDefaultLibrary(QStringLiteral("grantlee_i18ntags"));
   }
 
 private Q_SLOTS:
@@ -291,7 +291,6 @@ void TestInternationalization::testStrings_data()
 }
 
 typedef QHash<QString, QVariant> Dict;
-Q_DECLARE_METATYPE( Dict )
 
 void TestInternationalization::testLocalizedTemplate()
 {
@@ -328,23 +327,19 @@ void TestInternationalization::testLocalizedTemplate_data()
   QTest::addColumn<Dict>("dict");
 
   Dict dict;
-  dict.insert(QLatin1String("date"), QDate(2005, 5, 7) );
+  dict.insert(QStringLiteral("date"), QDate(2005, 5, 7) );
   QTest::newRow("fragment-01")
     << QString::fromLatin1("{% i18n '%1 messages at %2, fraction of total: %3. Rating : %4' _(1000) _(date) _(0.6) _(4.8) %}")
     << QString::fromLatin1("1,000 messages at 7 May 2005, fraction of total: 0.60. Rating : 4.80")
     << QString::fromLatin1("1,000 messages at 5/7/05, fraction of total: 0.60. Rating : 4.80")
     << QString::fromLatin1("1,000 messages at 07/05/2005, fraction of total: 0.60. Rating : 4.80")
     << QString::fromLatin1("1.000 Nachrichten am 07.05.05, ratio: 0,60. Bemessungen : 4,80")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromUtf8("1 000 messages au 07/05/05, la fraction du total: 0,60. Note: 4,80")
-#else
     << QString::fromUtf8("1 000 messages au 07/05/2005, la fraction du total: 0,60. Note: 4,80")
-#endif
     << dict;
 
-  dict.insert(QLatin1String("integer"), 1000);
-  dict.insert(QLatin1String("smallFloat"), 0.6);
-  dict.insert(QLatin1String("largeFloat"), 4.8);
+  dict.insert(QStringLiteral("integer"), 1000);
+  dict.insert(QStringLiteral("smallFloat"), 0.6);
+  dict.insert(QStringLiteral("largeFloat"), 4.8);
 
   QTest::newRow("fragment-02")
     << QString::fromLatin1("{% i18n '%1 messages at %2, fraction of total: %3. Rating : %4' _(integer) _(date) _(smallFloat) _(largeFloat) %}")
@@ -352,15 +347,11 @@ void TestInternationalization::testLocalizedTemplate_data()
     << QString::fromLatin1("1,000 messages at 5/7/05, fraction of total: 0.60. Rating : 4.80")
     << QString::fromLatin1("1,000 messages at 07/05/2005, fraction of total: 0.60. Rating : 4.80")
     << QString::fromLatin1("1.000 Nachrichten am 07.05.05, ratio: 0,60. Bemessungen : 4,80")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromUtf8("1 000 messages au 07/05/05, la fraction du total: 0,60. Note: 4,80")
-#else
     << QString::fromUtf8("1 000 messages au 07/05/2005, la fraction du total: 0,60. Note: 4,80")
-#endif
     << dict;
 
-  dict.insert(QLatin1String("time"), QTime(4, 5, 6));
-  dict.insert(QLatin1String("dateTime"), QDateTime(QDate(2005, 5, 7), QTime(4, 5, 6)));
+  dict.insert(QStringLiteral("time"), QTime(4, 5, 6));
+  dict.insert(QStringLiteral("dateTime"), QDateTime(QDate(2005, 5, 7), QTime(4, 5, 6)));
 
   QTest::newRow("fragment-03")
     << QString::fromLatin1("{{ _(integer) }} -- {{ _(date) }} -- {{ _(smallFloat) }} -- {{ _(largeFloat) }} -- {{ _(time) }} -- {{ _(dateTime) }}")
@@ -368,11 +359,7 @@ void TestInternationalization::testLocalizedTemplate_data()
     << QString::fromLatin1("1,000 -- 5/7/05 -- 0.60 -- 4.80 -- 4:05 AM -- 5/7/05 4:05 AM")
     << QString::fromLatin1("1,000 -- 07/05/2005 -- 0.60 -- 4.80 -- 04:05 -- 07/05/2005 04:05")
     << QString::fromLatin1("1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromUtf8("1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05")
-#else
     << QString::fromUtf8("1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05")
-#endif
     << dict;
 
   QTest::newRow("fragment-04")
@@ -386,41 +373,19 @@ void TestInternationalization::testLocalizedTemplate_data()
       "{% endwith_locale %}")
     << QString::fromUtf8("Today"           " -- 1,000 -- 7 May 2005 -- 0.60 -- 4.80 -- 04:05:06 -- 7 May 2005 04:05:06"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-                         "Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05")
-#else
                          "Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05")
-#endif
     << QString::fromUtf8("Today"           " -- 1,000 -- 5/7/05 -- 0.60 -- 4.80 -- 4:05 AM -- 5/7/05 4:05 AM"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-                         "Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05")
-#else
                          "Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05")
-#endif
     << QString::fromUtf8("Today"           " -- 1,000 -- 07/05/2005 -- 0.60 -- 4.80 -- 04:05 -- 07/05/2005 04:05"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-                         "Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05")
-#else
                          "Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05")
-#endif
     << QString::fromUtf8("Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-                         "Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05")
-#else
                          "Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05")
-#endif
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromUtf8("Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05"
-                         "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
-                         "Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05")
-#else
     << QString::fromUtf8("Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
                          "Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05")
-#endif
     << dict;
 
   QTest::newRow("fragment-05")
@@ -435,68 +400,40 @@ void TestInternationalization::testLocalizedTemplate_data()
       "{% endwith_locale %}")
     << QString::fromUtf8("Today"           " -- 1,000 -- 7 May 2005 -- 0.60 -- 4.80 -- 04:05:06 -- 7 May 2005 04:05:06"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-                         "Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05"
-#else
                          "Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05"
-#endif
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05")
     << QString::fromUtf8("Today"           " -- 1,000 -- 5/7/05 -- 0.60 -- 4.80 -- 4:05 AM -- 5/7/05 4:05 AM"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-                         "Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05"
-#else
                          "Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05"
-#endif
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05")
     << QString::fromUtf8("Today"           " -- 1,000 -- 07/05/2005 -- 0.60 -- 4.80 -- 04:05 -- 07/05/2005 04:05"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-                         "Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05"
-#else
                          "Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05"
-#endif
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05")
     << QString::fromUtf8("Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-                         "Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05"
-#else
                          "Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05"
-#endif
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromUtf8("Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05"
-                         "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
-                         "Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05"
-                         "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05")
-#else
     << QString::fromUtf8("Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05"
                          "Aujourd&#39;hui" " -- 1 000 -- 07/05/2005 -- 0,60 -- 4,80 -- 04:05 -- 07/05/2005 04:05"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05")
-#endif
     << dict;
 
-  dict.insert( QLatin1String( "list" ), QVariantList() << 1000);
+  dict.insert( QStringLiteral( "list" ), QVariantList() << 1000);
   QTest::newRow("fragment-06")
     << QString::fromLatin1("{{ _(list.0) }}")
       << QString::fromUtf8( "1,000" )
       << QString::fromUtf8( "1,000" )
       << QString::fromUtf8( "1,000" )
       << QString::fromUtf8( "1.000" )
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-      << QString::fromUtf8( "1 000" )
-#else
-      << QString::fromUtf8( "1 000" )
-#endif
-      << dict;
+      << QString::fromUtf8( "1 000" ) << dict;
 
   dict.clear();
-  dict.insert(QLatin1String("longlong"), (qlonglong)1000);
-  dict.insert(QLatin1String("float"), (float)0.6);
-  dict.insert(QLatin1String("double"), (float)4.8);
-  dict.insert(QLatin1String("hash"), QVariantHash());
+  dict.insert(QStringLiteral("longlong"), (qlonglong)1000);
+  dict.insert(QStringLiteral("float"), (float)0.6);
+  dict.insert(QStringLiteral("double"), (float)4.8);
+  dict.insert(QStringLiteral("hash"), QVariantHash());
 
   QTest::newRow("fragment-07")
     << QString::fromLatin1("{{ _(longlong) }} {{ _(float) }} {{ _(double) }}{{ _(hash) }}")
@@ -541,46 +478,30 @@ void TestInternationalization::testSafeContent_data()
   QTest::addColumn<Dict>("dict");
 
   Dict dict;
-  dict.insert(QLatin1String("date"), QDate(2005, 5, 7) );
+  dict.insert(QStringLiteral("date"), QDate(2005, 5, 7) );
 
   QTest::newRow("safe-01")
     << QString::fromLatin1("{% i18n 'Today is %1' _(date) %}")
     << QString::fromLatin1("Today is 7 May 2005")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromUtf8("Aujourd&#39;hui est 07/05/05")
-#else
     << QString::fromUtf8("Aujourd&#39;hui est 07/05/2005")
-#endif
     << dict;
 
   QTest::newRow("safe-02")
     << QString::fromLatin1("{% autoescape off %}{% i18n 'Today is %1' _(date) %}{% endautoescape %}")
     << QString::fromLatin1("Today is 7 May 2005")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromUtf8("Aujourd'hui est 07/05/05")
-#else
     << QString::fromUtf8("Aujourd'hui est 07/05/2005")
-#endif
     << dict;
 
   QTest::newRow("safe-03")
     << QString::fromLatin1("{% i18n_var 'Today is %1' _(date) as today_greeting %}-{{ today_greeting }}-")
     << QString::fromLatin1("-Today is 7 May 2005-")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromUtf8("-Aujourd&#39;hui est 07/05/05-")
-#else
     << QString::fromUtf8("-Aujourd&#39;hui est 07/05/2005-")
-#endif
     << dict;
 
   QTest::newRow("safe-04")
     << QString::fromLatin1("{% autoescape off %}{% i18n_var 'Today is %1' _(date) as today_greeting %}-{{ today_greeting }}-{% endautoescape %}")
     << QString::fromLatin1("-Today is 7 May 2005-")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromUtf8("-Aujourd'hui est 07/05/05-")
-#else
     << QString::fromUtf8("-Aujourd'hui est 07/05/2005-")
-#endif
     << dict;
 
   QTest::newRow("safe-05")
@@ -595,7 +516,7 @@ void TestInternationalization::testSafeContent_data()
     << QString::fromUtf8("-Aujourd'hui-")
     << dict;
 
-  dict.insert( QLatin1String( "today_text" ), QLatin1String( "Today" ) );
+  dict.insert( QStringLiteral( "today_text" ), QStringLiteral( "Today" ) );
 
   QTest::newRow("safe-07")
     << QString::fromLatin1("-{{ _(today_text) }}-")
@@ -609,7 +530,7 @@ void TestInternationalization::testSafeContent_data()
     << QString::fromUtf8("-Aujourd'hui-")
     << dict;
 
-  dict.insert( QLatin1String( "today_and_tomorrow_text" ), markSafe( QString::fromLatin1( "Today &amp; tomorrow" ) ) );
+  dict.insert( QStringLiteral( "today_and_tomorrow_text" ), markSafe( QString::fromLatin1( "Today &amp; tomorrow" ) ) );
 
   QTest::newRow("safe-09")
     << QString::fromLatin1("-{{ _(today_and_tomorrow_text) }}-")
@@ -798,11 +719,7 @@ void TestInternationalization::testDates_data()
     << QString::fromLatin1("5/9/10")
     << QString::fromLatin1("09/05/2010")
     << QString::fromLatin1("09.05.10")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromLatin1("09/05/10");
-#else
     << QString::fromLatin1("09/05/2010");
-#endif
 
   QTest::newRow("date-02")
     << QDate(2010, 10, 11)
@@ -810,11 +727,7 @@ void TestInternationalization::testDates_data()
     << QString::fromLatin1("10/11/10")
     << QString::fromLatin1("11/10/2010")
     << QString::fromLatin1("11.10.10")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromLatin1("11/10/10");
-#else
     << QString::fromLatin1("11/10/2010");
-#endif
 }
 
 void TestInternationalization::testIntegers()
@@ -991,11 +904,7 @@ void TestInternationalization::testDateTimes_data()
     << QString::fromLatin1("6/7/05 5:06 AM")
     << QString::fromLatin1("07/06/2005 05:06")
     << QString::fromLatin1("07.06.05 05:06")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromLatin1("07/06/05 05:06");
-#else
     << QString::fromLatin1("07/06/2005 05:06");
-#endif
 
   QTest::newRow("datetime-02")
     << QDateTime(QDate(2005, 6, 7), QTime(11, 12, 13))
@@ -1003,11 +912,7 @@ void TestInternationalization::testDateTimes_data()
     << QString::fromLatin1("6/7/05 11:12 AM")
     << QString::fromLatin1("07/06/2005 11:12")
     << QString::fromLatin1("07.06.05 11:12")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromLatin1("07/06/05 11:12");
-#else
     << QString::fromLatin1("07/06/2005 11:12");
-#endif
 
   QTest::newRow("datetime-03")
     << QDateTime(QDate(2005, 6, 7), QTime(15, 12, 13))
@@ -1015,11 +920,7 @@ void TestInternationalization::testDateTimes_data()
     << QString::fromLatin1("6/7/05 3:12 PM")
     << QString::fromLatin1("07/06/2005 15:12")
     << QString::fromLatin1("07.06.05 15:12")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromLatin1("07/06/05 15:12");
-#else
     << QString::fromLatin1("07/06/2005 15:12");
-#endif
 
   QTest::newRow("datetime-04")
     << QDateTime(QDate(2005, 10, 11), QTime(5, 6, 7))
@@ -1027,11 +928,7 @@ void TestInternationalization::testDateTimes_data()
     << QString::fromLatin1("10/11/05 5:06 AM")
     << QString::fromLatin1("11/10/2005 05:06")
     << QString::fromLatin1("11.10.05 05:06")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromLatin1("11/10/05 05:06");
-#else
     << QString::fromLatin1("11/10/2005 05:06");
-#endif
 
   QTest::newRow("datetime-05")
     << QDateTime(QDate(2005, 10, 11), QTime(11, 12, 13))
@@ -1039,11 +936,7 @@ void TestInternationalization::testDateTimes_data()
     << QString::fromLatin1("10/11/05 11:12 AM")
     << QString::fromLatin1("11/10/2005 11:12")
     << QString::fromLatin1("11.10.05 11:12")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromLatin1("11/10/05 11:12");
-#else
     << QString::fromLatin1("11/10/2005 11:12");
-#endif
 
   QTest::newRow("datetime-06")
     << QDateTime(QDate(2005, 10, 11), QTime(15, 12, 13))
@@ -1051,11 +944,7 @@ void TestInternationalization::testDateTimes_data()
     << QString::fromLatin1("10/11/05 3:12 PM")
     << QString::fromLatin1("11/10/2005 15:12")
     << QString::fromLatin1("11.10.05 15:12")
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    << QString::fromLatin1("11/10/05 15:12");
-#else
     << QString::fromLatin1("11/10/2005 15:12");
-#endif
 
 }
 
