@@ -33,35 +33,35 @@ BBCodeBuilder::~BBCodeBuilder()
 
 void BBCodeBuilder::beginStrong()
 {
-  m_text.append( QLatin1String( "[B]" ) );
+  m_text.append( QStringLiteral( "[B]" ) );
 }
 void BBCodeBuilder::endStrong()
 {
-  m_text.append( QLatin1String( "[/B]" ) );
+  m_text.append( QStringLiteral( "[/B]" ) );
 }
 void BBCodeBuilder::beginEmph()
 {
-  m_text.append( QLatin1String( "[I]" ) );
+  m_text.append( QStringLiteral( "[I]" ) );
 }
 void BBCodeBuilder::endEmph()
 {
-  m_text.append( QLatin1String( "[/I]" ) );
+  m_text.append( QStringLiteral( "[/I]" ) );
 }
 void BBCodeBuilder::beginUnderline()
 {
-  m_text.append( QLatin1String( "[U]" ) );
+  m_text.append( QStringLiteral( "[U]" ) );
 }
 void BBCodeBuilder::endUnderline()
 {
-  m_text.append( QLatin1String( "[/U]" ) );
+  m_text.append( QStringLiteral( "[/U]" ) );
 }
 void BBCodeBuilder::beginStrikeout()
 {
-  m_text.append( QLatin1String( "[S]" ) );
+  m_text.append( QStringLiteral( "[S]" ) );
 }
 void BBCodeBuilder::endStrikeout()
 {
-  m_text.append( QLatin1String( "[/S]" ) );
+  m_text.append( QStringLiteral( "[/S]" ) );
 }
 void BBCodeBuilder::beginForeground( const QBrush &brush )
 {
@@ -69,7 +69,7 @@ void BBCodeBuilder::beginForeground( const QBrush &brush )
 }
 void BBCodeBuilder::endForeground()
 {
-  m_text.append( QLatin1String( "[/COLOR]" ) );
+  m_text.append( QStringLiteral( "[/COLOR]" ) );
 }
 
 // Background colour not supported by BBCode.
@@ -81,7 +81,7 @@ void BBCodeBuilder::beginAnchor( const QString &href, const QString &name )
 }
 void BBCodeBuilder::endAnchor()
 {
-  m_text.append( QLatin1String( "[/URL]" ) );
+  m_text.append( QStringLiteral( "[/URL]" ) );
 }
 
 // Font family not supported by BBCode.
@@ -92,7 +92,7 @@ void BBCodeBuilder::beginFontPointSize( int size )
 }
 void BBCodeBuilder::endFontPointSize()
 {
-  m_text.append( QLatin1String( "[/SIZE]" ) );
+  m_text.append( QStringLiteral( "[/SIZE]" ) );
 }
 
 void BBCodeBuilder::beginParagraph( Qt::Alignment a, qreal top, qreal bottom, qreal left, qreal right )
@@ -102,9 +102,9 @@ void BBCodeBuilder::beginParagraph( Qt::Alignment a, qreal top, qreal bottom, qr
   Q_UNUSED( left );
   Q_UNUSED( right );
   if ( a & Qt::AlignRight ) {
-    m_text.append( QLatin1String( "\n[Right]" ) );
+    m_text.append( QStringLiteral( "\n[Right]" ) );
   } else if ( a & Qt::AlignHCenter ) {
-    m_text.append( QLatin1String( "\n[CENTER]" ) );
+    m_text.append( QStringLiteral( "\n[CENTER]" ) );
   }
   // LEFT is also supported in BBCode, but ignored.
   m_currentAlignment = a;
@@ -113,9 +113,9 @@ void BBCodeBuilder::beginParagraph( Qt::Alignment a, qreal top, qreal bottom, qr
 void BBCodeBuilder::endParagraph()
 {
   if ( m_currentAlignment & Qt::AlignRight ) {
-    m_text.append( QLatin1String( "\n[/Right]\n" ) );
+    m_text.append( QStringLiteral( "\n[/Right]\n" ) );
   } else if ( m_currentAlignment & Qt::AlignHCenter ) {
-    m_text.append( QLatin1String( "\n[/CENTER]\n" ) );
+    m_text.append( QStringLiteral( "\n[/CENTER]\n" ) );
   } else {
     m_text.append( QLatin1Char( '\n' ) );
   }
@@ -140,16 +140,16 @@ void BBCodeBuilder::beginList( QTextListFormat::Style type )
   case QTextListFormat::ListDisc:
   case QTextListFormat::ListCircle:
   case QTextListFormat::ListSquare:
-    m_text.append( QLatin1String( "[LIST]\n" ) );   // Unordered lists are all disc type in BBCode.
+    m_text.append( QStringLiteral( "[LIST]\n" ) );   // Unordered lists are all disc type in BBCode.
     break;
   case QTextListFormat::ListDecimal:
-    m_text.append( QLatin1String( "[LIST=1]\n" ) );
+    m_text.append( QStringLiteral( "[LIST=1]\n" ) );
     break;
   case QTextListFormat::ListLowerAlpha:
-    m_text.append( QLatin1String( "[LIST=a]\n" ) );
+    m_text.append( QStringLiteral( "[LIST=a]\n" ) );
     break;
   case QTextListFormat::ListUpperAlpha:
-    m_text.append( QLatin1String( "[LIST=A]\n" ) );
+    m_text.append( QStringLiteral( "[LIST=A]\n" ) );
     break;
   default:
     break;
@@ -158,43 +158,43 @@ void BBCodeBuilder::beginList( QTextListFormat::Style type )
 
 void BBCodeBuilder::endList()
 {
-  m_text.append( QLatin1String( "[/LIST]\n" ) );
+  m_text.append( QStringLiteral( "[/LIST]\n" ) );
 }
 
 void BBCodeBuilder::beginListItem()
 {
-  m_text.append( QLatin1String( "[*] " ) );
+  m_text.append( QStringLiteral( "[*] " ) );
 }
 
 void BBCodeBuilder::beginSuperscript()
 {
-  m_text.append( QLatin1String( "[SUP]" ) );
+  m_text.append( QStringLiteral( "[SUP]" ) );
 }
 
 void BBCodeBuilder::endSuperscript()
 {
-  m_text.append( QLatin1String( "[/SUP]" ) );
+  m_text.append( QStringLiteral( "[/SUP]" ) );
 }
 
 void BBCodeBuilder::beginSubscript()
 {
-  m_text.append( QLatin1String( "[SUB]" ) );
+  m_text.append( QStringLiteral( "[SUB]" ) );
 }
 
 void BBCodeBuilder::endSubscript()
 {
-  m_text.append( QLatin1String( "[/SUB]" ) );
+  m_text.append( QStringLiteral( "[/SUB]" ) );
 }
 
 
 void BBCodeBuilder::beginTable( qreal, qreal, const QString & )
 {
-  m_text.append( QLatin1String( "[TABLE]\n" ) );
+  m_text.append( QStringLiteral( "[TABLE]\n" ) );
 }
 
 void BBCodeBuilder::beginTableRow()
 {
-  m_text.append( QLatin1String( "[/TABLE]" ) );
+  m_text.append( QStringLiteral( "[/TABLE]" ) );
 }
 
 void BBCodeBuilder::appendLiteralText( const QString &text )
@@ -205,7 +205,7 @@ void BBCodeBuilder::appendLiteralText( const QString &text )
 const QString BBCodeBuilder::escape( const QString &s ) const
 {
   if ( s.contains( QLatin1Char( '[' ) ) ) {
-    return QLatin1String( "[NOPARSE]" ) + s + QLatin1String( "[/NOPARSE]" );
+    return QStringLiteral( "[NOPARSE]" ) + s + QStringLiteral( "[/NOPARSE]" );
   }
   return s;
 }
