@@ -18,9 +18,9 @@
 
 */
 
-#include <QtTest>
+#include <QtTest/QtTest>
 #include <QtCore>
-#include <qtestevent.h>
+#include <QtTest/qtestevent.h>
 #include <QtCore/QRegExp>
 #include <QtGui/QTextCursor>
 #include <QtGui/QTextDocument>
@@ -70,13 +70,13 @@ void TestPlainMarkupOutput::testSingleFormat()
     QTextDocument *doc = new QTextDocument();
 
     // One format
-    doc->setHtml( QLatin1String( "This <b>text</b> is bold." ) );
+    doc->setHtml( QStringLiteral( "This <b>text</b> is bold." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
-    QRegExp regex(QLatin1String("^This \\*text\\* is bold.\\n$"));
+    QRegExp regex(QStringLiteral("^This \\*text\\* is bold.\\n$"));
 
     QVERIFY(regex.exactMatch(result));
 
@@ -87,13 +87,13 @@ void TestPlainMarkupOutput::testDoubleFormat()
     QTextDocument *doc = new QTextDocument();
 
     // One format
-    doc->setHtml( QLatin1String( "Some <b><i>formatted</i></b> text." ) );
+    doc->setHtml( QStringLiteral( "Some <b><i>formatted</i></b> text." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
-    QRegExp regex(QLatin1String("^Some (\\*/|/\\*)formatted(\\*/|/\\*) text.\\n$"));
+    QRegExp regex(QStringLiteral("^Some (\\*/|/\\*)formatted(\\*/|/\\*) text.\\n$"));
 
     QVERIFY(regex.exactMatch(result));
 
@@ -102,14 +102,14 @@ void TestPlainMarkupOutput::testDoubleFormat()
 void TestPlainMarkupOutput::testAnchor()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "A <a href=\"http://www.kde.org\">link</a> to KDE." ) );
+    doc->setHtml( QStringLiteral( "A <a href=\"http://www.kde.org\">link</a> to KDE." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex(QLatin1String("^A link\\[1\\] to KDE.\\n\\n--------\\n\\[1\\] http://www.kde.org\\n$"));
+    QRegExp regex(QStringLiteral("^A link\\[1\\] to KDE.\\n\\n--------\\n\\[1\\] http://www.kde.org\\n$"));
 
     regex.exactMatch(result);
 
@@ -122,7 +122,7 @@ void TestPlainMarkupOutput::testAnchor()
 void TestPlainMarkupOutput::testAnchorWithFormattedContent()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "A <a href=\"http://www.kde.org\"><b>formatted</b> link</a> to KDE." ) );
+    doc->setHtml( QStringLiteral( "A <a href=\"http://www.kde.org\"><b>formatted</b> link</a> to KDE." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
@@ -130,7 +130,7 @@ void TestPlainMarkupOutput::testAnchorWithFormattedContent()
     QString result = hb->getResult();
 
 
-    QRegExp regex(QLatin1String("^A \\*formatted\\* link\\[1\\] to KDE.\\n\\n--------\\n\\[1\\] http://www.kde.org\\n$"));
+    QRegExp regex(QStringLiteral("^A \\*formatted\\* link\\[1\\] to KDE.\\n\\n--------\\n\\[1\\] http://www.kde.org\\n$"));
 
     QVERIFY(regex.exactMatch(result));
 
@@ -139,14 +139,14 @@ void TestPlainMarkupOutput::testAnchorWithFormattedContent()
 void TestPlainMarkupOutput::testAdjacentAnchors()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "Two <a href=\"http://www.kde.org\">links</a><a href=\"http://www.google.com\">next</a> to eachother." ) );
+    doc->setHtml( QStringLiteral( "Two <a href=\"http://www.kde.org\">links</a><a href=\"http://www.google.com\">next</a> to eachother." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex(QLatin1String("^Two links\\[1\\]next\\[2\\] to eachother.\\n\\n--------\\n\\[1\\] http://www.kde.org\\n\\[2\\] http://www.google.com\\n$"));
+    QRegExp regex(QStringLiteral("^Two links\\[1\\]next\\[2\\] to eachother.\\n\\n--------\\n\\[1\\] http://www.kde.org\\n\\[2\\] http://www.google.com\\n$"));
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -154,14 +154,14 @@ void TestPlainMarkupOutput::testAdjacentAnchors()
 void TestPlainMarkupOutput::testNestedFormatting()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "This <b>text is <i>italic</i> and</b> bold." ) );
+    doc->setHtml( QStringLiteral( "This <b>text is <i>italic</i> and</b> bold." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex(QLatin1String("^This \\*text is /italic/ and\\* bold.\\n$"));
+    QRegExp regex(QStringLiteral("^This \\*text is /italic/ and\\* bold.\\n$"));
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -169,14 +169,14 @@ void TestPlainMarkupOutput::testNestedFormatting()
 void TestPlainMarkupOutput::testSpan()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "Some <span style=\"color:#ff0000;\">formatted</span> text." ) );
+    doc->setHtml( QStringLiteral( "Some <span style=\"color:#ff0000;\">formatted</span> text." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp( QLatin1String( "^Some formatted text.\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Some formatted text.\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -184,7 +184,7 @@ void TestPlainMarkupOutput::testSpan()
 void TestPlainMarkupOutput::testDoubleSpan()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "Some <span style=\"color:#ff0000;background-color:#00ff00;\">formatted</span> text." ) );
+    doc->setHtml( QStringLiteral( "Some <span style=\"color:#ff0000;background-color:#00ff00;\">formatted</span> text." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
@@ -192,7 +192,7 @@ void TestPlainMarkupOutput::testDoubleSpan()
     QString result = hb->getResult();
 
 
-    QRegExp regex = QRegExp( QLatin1String( "^Some formatted text.\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Some formatted text.\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 
@@ -201,14 +201,14 @@ void TestPlainMarkupOutput::testDoubleSpan()
 void TestPlainMarkupOutput::testSpanNesting()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "Paragraph <span style=\"background-color:#00ff00;\">with some <span style=\"color:#ff0000;\">formatted</span> nested</span> text." ) );
+    doc->setHtml( QStringLiteral( "Paragraph <span style=\"background-color:#00ff00;\">with some <span style=\"color:#ff0000;\">formatted</span> nested</span> text." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp( QLatin1String( "^Paragraph with some formatted nested text.\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Paragraph with some formatted nested text.\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -216,14 +216,14 @@ void TestPlainMarkupOutput::testSpanNesting()
 void TestPlainMarkupOutput::testDoubleStartDifferentFinish()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "Paragraph <i><b>with</b> some formatted</i> text." ) );
+    doc->setHtml( QStringLiteral( "Paragraph <i><b>with</b> some formatted</i> text." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp( QLatin1String( "^Paragraph /\\*with\\* some formatted/ text.\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Paragraph /\\*with\\* some formatted/ text.\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -231,14 +231,14 @@ void TestPlainMarkupOutput::testDoubleStartDifferentFinish()
 void TestPlainMarkupOutput::testDoubleStartDifferentFinishReverseOrder()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "Paragraph <b><i>with</i> some formatted</b> text." ) );
+    doc->setHtml( QStringLiteral( "Paragraph <b><i>with</i> some formatted</b> text." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp( QLatin1String( "^Paragraph \\*/with/ some formatted\\* text.\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Paragraph \\*/with/ some formatted\\* text.\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 
@@ -247,14 +247,14 @@ void TestPlainMarkupOutput::testDoubleStartDifferentFinishReverseOrder()
 void TestPlainMarkupOutput::testDifferentStartDoubleFinish()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "Paragraph <i>with some <b>formatted<b></i> text." ) );
+    doc->setHtml( QStringLiteral( "Paragraph <i>with some <b>formatted<b></i> text." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp( QLatin1String( "^Paragraph /with some \\*formatted\\*/ text.\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Paragraph /with some \\*formatted\\*/ text.\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -262,7 +262,7 @@ void TestPlainMarkupOutput::testDifferentStartDoubleFinish()
 void TestPlainMarkupOutput::testDifferentStartDoubleFinishReverseOrder()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "Paragraph <b>with some <i>formatted</i></b> text." ) );
+    doc->setHtml( QStringLiteral( "Paragraph <b>with some <i>formatted</i></b> text." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
@@ -270,7 +270,7 @@ void TestPlainMarkupOutput::testDifferentStartDoubleFinishReverseOrder()
     QString result = hb->getResult();
 
 
-    QRegExp regex = QRegExp( QLatin1String( "^Paragraph \\*with some /formatted/\\* text.\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Paragraph \\*with some /formatted/\\* text.\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 
@@ -279,7 +279,7 @@ void TestPlainMarkupOutput::testDifferentStartDoubleFinishReverseOrder()
 void TestPlainMarkupOutput::testOverlap()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "Paragraph <b>with <i>some</i></b><i> formatted</i> text." ) );
+    doc->setHtml( QStringLiteral( "Paragraph <b>with <i>some</i></b><i> formatted</i> text." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
@@ -287,7 +287,7 @@ void TestPlainMarkupOutput::testOverlap()
     QString result = hb->getResult();
 
 
-    QRegExp regex = QRegExp( QLatin1String( "^Paragraph \\*with /some/\\*/ formatted/ text.\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Paragraph \\*with /some/\\*/ formatted/ text.\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 
@@ -296,14 +296,14 @@ void TestPlainMarkupOutput::testOverlap()
 void TestPlainMarkupOutput::testEdgeCaseLeft()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "Paragraph <b>with some formatted text.</b>" ) );
+    doc->setHtml( QStringLiteral( "Paragraph <b>with some formatted text.</b>" ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp( QLatin1String( "^Paragraph \\*with some formatted text.\\*\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Paragraph \\*with some formatted text.\\*\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -311,14 +311,14 @@ void TestPlainMarkupOutput::testEdgeCaseLeft()
 void TestPlainMarkupOutput::testEdgeCaseRight()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "<b>Paragraph with some formatted</b> text." ) );
+    doc->setHtml( QStringLiteral( "<b>Paragraph with some formatted</b> text." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp( QLatin1String( "^\\*Paragraph with some formatted\\* text.\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^\\*Paragraph with some formatted\\* text.\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -326,14 +326,14 @@ void TestPlainMarkupOutput::testEdgeCaseRight()
 void TestPlainMarkupOutput::testImage()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" /> image." ) );
+    doc->setHtml( QStringLiteral( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" /> image." ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp( QLatin1String( "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] http://kde.org/img/kde41.png\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] http://kde.org/img/kde41.png\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -347,7 +347,7 @@ void TestPlainMarkupOutput::testImageResized()
     QTextDocument *doc = new QTextDocument();
 
     // width
-    doc->setHtml( QLatin1String( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" width=\"10\" /> image." ) );
+    doc->setHtml( QStringLiteral( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" width=\"10\" /> image." ) );
 
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
@@ -355,29 +355,29 @@ void TestPlainMarkupOutput::testImageResized()
     result = hb->getResult();
 
 
-    regex = QRegExp( QLatin1String( "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] http://kde.org/img/kde41.png\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] http://kde.org/img/kde41.png\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // height
-    doc->setHtml( QLatin1String( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" height=\"10\" /> image." ) );
+    doc->setHtml( QStringLiteral( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" height=\"10\" /> image." ) );
 
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] http://kde.org/img/kde41.png\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] http://kde.org/img/kde41.png\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // height and width
-    doc->setHtml( QLatin1String( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" height=\"10\" width=\"10\" /> image." ) );
+    doc->setHtml( QStringLiteral( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" height=\"10\" width=\"10\" /> image." ) );
 
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] http://kde.org/img/kde41.png\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Paragraph with an inline \\[1\\] image.\\n\\n--------\\n\\[1\\] http://kde.org/img/kde41.png\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -392,105 +392,105 @@ void TestPlainMarkupOutput::testEachFormatTagSingly()
 
 
     // Test bold
-    doc->setHtml( QLatin1String( "Some <b>formatted</b> text." ) );
+    doc->setHtml( QStringLiteral( "Some <b>formatted</b> text." ) );
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Some \\*formatted\\* text.\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Some \\*formatted\\* text.\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
 
     // Test Italic
-    doc->setHtml( QLatin1String( "Some <i>formatted</i> text." ) );
+    doc->setHtml( QStringLiteral( "Some <i>formatted</i> text." ) );
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Some /formatted/ text.\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Some /formatted/ text.\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Underline
-    doc->setHtml( QLatin1String( "Some <u>formatted</u> text." ) );
+    doc->setHtml( QStringLiteral( "Some <u>formatted</u> text." ) );
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Some _formatted_ text.\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Some _formatted_ text.\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Strikeout
-    doc->setHtml( QLatin1String( "Some <s>formatted</s> text." ) );
+    doc->setHtml( QStringLiteral( "Some <s>formatted</s> text." ) );
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Some -formatted- text.\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Some -formatted- text.\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Superscript
-    doc->setHtml( QLatin1String( "Some <sup>formatted</sup> text." ) );
+    doc->setHtml( QStringLiteral( "Some <sup>formatted</sup> text." ) );
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Some \\^\\{formatted\\} text.\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Some \\^\\{formatted\\} text.\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Subscript
-    doc->setHtml( QLatin1String( "Some <sub>formatted</sub> text." ) );
+    doc->setHtml( QStringLiteral( "Some <sub>formatted</sub> text." ) );
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Some _\\{formatted\\} text.\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Some _\\{formatted\\} text.\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Foreground
-    doc->setHtml( QLatin1String( "Some <span style=\"color:#ff0000;\">formatted</span> text." ) );
+    doc->setHtml( QStringLiteral( "Some <span style=\"color:#ff0000;\">formatted</span> text." ) );
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Some formatted text.\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Some formatted text.\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
 
     // Test Background
-    doc->setHtml( QLatin1String( "Some <span style=\"background-color:#ff0000;\">formatted</span> text." ) );
+    doc->setHtml( QStringLiteral( "Some <span style=\"background-color:#ff0000;\">formatted</span> text." ) );
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Some formatted text.\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Some formatted text.\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Font Family
-    doc->setHtml( QLatin1String( "Some <span style=\"font-family:courier;\">formatted</span> text." ) );
+    doc->setHtml( QStringLiteral( "Some <span style=\"font-family:courier;\">formatted</span> text." ) );
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Some formatted text.\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Some formatted text.\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Font Size
-    doc->setHtml( QLatin1String( "Some <span style=\"font-size:20pt;\">formatted</span> text." ) );
+    doc->setHtml( QStringLiteral( "Some <span style=\"font-size:20pt;\">formatted</span> text." ) );
     hb = new PlainTextMarkupBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp( QLatin1String( "^Some formatted text.\\n$" ) );
+    regex = QRegExp( QStringLiteral( "^Some formatted text.\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
 }
@@ -498,7 +498,7 @@ void TestPlainMarkupOutput::testEachFormatTagSingly()
 void TestPlainMarkupOutput::testHorizontalRule()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "<p style=\"margin-top:0;margin-bottom:0;\">Foo</p><hr /><p style=\"margin-top:0;margin-bottom:0;\">Bar</p>" ) );
+    doc->setHtml( QStringLiteral( "<p style=\"margin-top:0;margin-bottom:0;\">Foo</p><hr /><p style=\"margin-top:0;margin-bottom:0;\">Bar</p>" ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
@@ -506,7 +506,7 @@ void TestPlainMarkupOutput::testHorizontalRule()
     QString result = hb->getResult();
 
 
-    QRegExp regex = QRegExp( QLatin1String( "^Foo\\n--------------------\\nBar\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Foo\\n--------------------\\nBar\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -514,14 +514,14 @@ void TestPlainMarkupOutput::testHorizontalRule()
 void TestPlainMarkupOutput::testNewlines()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "<p>Foo</p>\n<br /><br />\n<p>Bar</p>" ) );
+    doc->setHtml( QStringLiteral( "<p>Foo</p>\n<br /><br />\n<p>Bar</p>" ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp( QLatin1String( "^Foo\\n\\n\\nBar\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Foo\\n\\n\\nBar\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -529,14 +529,14 @@ void TestPlainMarkupOutput::testNewlines()
 void TestPlainMarkupOutput::testEmptyParagraphs()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "<p>Foo</p>\n<br /><br />\n<p>Bar</p>" ) );
+    doc->setHtml( QStringLiteral( "<p>Foo</p>\n<br /><br />\n<p>Bar</p>" ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp( QLatin1String( "^Foo\\n\\n\\nBar\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Foo\\n\\n\\nBar\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -546,18 +546,18 @@ void TestPlainMarkupOutput::testNewlinesThroughQTextCursor()
     QTextDocument *doc = new QTextDocument(this);
     QTextCursor cursor(doc);
     cursor.movePosition(QTextCursor::Start);
-    cursor.insertText( QLatin1String( "Foo" ) );
-    cursor.insertText( QLatin1String( "\n" ) );
-    cursor.insertText( QLatin1String( "\n" ) );
-    cursor.insertText( QLatin1String( "\n" ) );
-    cursor.insertText( QLatin1String( "Bar" ) );
+    cursor.insertText( QStringLiteral( "Foo" ) );
+    cursor.insertText( QStringLiteral( "\n" ) );
+    cursor.insertText( QStringLiteral( "\n" ) );
+    cursor.insertText( QStringLiteral( "\n" ) );
+    cursor.insertText( QStringLiteral( "Bar" ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp( QLatin1String( "^Foo\\n\\n\\nBar\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Foo\\n\\n\\nBar\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -566,7 +566,7 @@ void TestPlainMarkupOutput:: testBrInsideParagraph()
 {
 
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml( QLatin1String( "<p>Foo<br /><br /><br />Bar</p>" ) );
+    doc->setHtml( QStringLiteral( "<p>Foo<br /><br /><br />Bar</p>" ) );
 
     PlainTextMarkupBuilder *hb = new PlainTextMarkupBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
@@ -575,7 +575,7 @@ void TestPlainMarkupOutput:: testBrInsideParagraph()
 
     // Two paragraphs separated by two line breaks
 
-    QRegExp regex = QRegExp( QLatin1String( "^Foo\\n\\n\\nBar\\n$" ) );
+    QRegExp regex = QRegExp( QStringLiteral( "^Foo\\n\\n\\nBar\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
